@@ -2,6 +2,10 @@
  * picker applet. Much of this is adapted from modemlights/properties.c
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "charpick.h"
 
 static void
@@ -14,24 +18,50 @@ update_default_list_cb (GtkEditable *editable, gpointer data)
   text = gtk_editable_get_chars (editable, 0, -1);
   if (!text)
   	return;
-  	
-  if (g_utf8_strlen (text, -1) == 0) {
-    gchar *old_text = g_locale_to_utf8 (curr_data->charlist, -1, NULL, NULL, NULL);
-    gint pos;
-    gtk_editable_insert_text (editable, old_text, -1, &pos);
-    g_free (old_text);
-    return;
+  g_strstrip (text);	
+  if (g_utf8_strlen (text, -1) == 0){
+  	g_free (text);
+  	g_print ("zero length \n");
+  	return;
   }
-  
+  	
   if (curr_data->default_charlist)
     g_free (curr_data->default_charlist	);
-  curr_data->default_charlist = g_locale_from_utf8 (text, -1, NULL, NULL, NULL);
+  curr_data->default_charlist = g_convert (text, -1, "ISO-8859-1", "UTF-8", 
+  					   NULL, NULL, NULL);
   
   panel_applet_gconf_set_string (applet, "default_list", text, NULL);
   g_free (text);
   
 }
 
+static void
+set_atk_relation (GtkWidget *label, GtkWidget *widget)
+{
+  AtkObject *atk_widget;
+  AtkObject *atk_label;
+  AtkRelationSet *relation_set;
+  AtkRelation *relation;
+  AtkObject *targets[1];
+
+  atk_widget = gtk_widget_get_accessible (widget);
+  atk_label = gtk_widget_get_accessible (label);
+  
+  /* return if gail is not loaded */
+  if (GTK_IS_ACCESSIBLE (atk_widget) == FALSE)
+    return;
+
+  /* set label-for relation */
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);	
+  
+  /* set label-by relation */
+  relation_set = atk_object_ref_relation_set (atk_widget);
+  targets[0] = atk_label;
+  relation = atk_relation_new (targets, 1, ATK_RELATION_LABELLED_BY);
+  atk_relation_set_add (relation_set, relation);
+  g_object_unref (G_OBJECT (relation)); 
+}
+
 static void default_chars_frame_create(charpick_data *curr_data)
 {
   GtkWidget *propwindow = curr_data->propwindow;
@@ -48,11 +78,14 @@ static void default_chars_frame_create(charpick_data *curr_data)
   default_list_hbox = gtk_hbox_new(FALSE, 5);
   default_list_label = gtk_label_new(_("Default character list:"));
   default_list_entry = gtk_entry_new_with_max_length (MAX_BUTTONS);
-  text_utf8 = g_locale_to_utf8 (curr_data->default_charlist, -1,
-  				NULL, NULL, NULL);
+  text_utf8 = g_convert (curr_data->default_charlist, -1, "UTF-8", 
+  			 "ISO-8859-1", NULL, NULL, NULL);
   gtk_entry_set_text(GTK_ENTRY(default_list_entry), 
 		     text_utf8);
   g_free (text_utf8);
+  set_atk_relation (default_list_label, default_list_entry);
+  set_atk_name_description (default_list_entry, _("Default list of characters"), 
+              _("Set the default character list here"));
 
   explain_label = gtk_label_new(_("These characters will appear when the panel"
                                   " is started. To return to this list, hit"
