@@ -25,6 +25,7 @@
 #include <libgnomeui/libgnomeui.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h> 
+#include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <time.h>
 
@@ -91,6 +92,11 @@
 		/*  properties vars */
  	 
 		GtkWidget *tik_syms_entry;
+		GtkWidget *proxy_url_entry;
+		GtkWidget *proxy_port_entry;
+		GtkWidget *proxy_user_entry;
+		GtkWidget *proxy_passwd_entry;
+		GtkWidget *proxy_auth_button;
 
 		GtkWidget *fontDialog;
 
@@ -115,7 +121,7 @@
 	char *getSymsFromClist(GtkWidget *clist) ;
 
 	char *splitPrice(char *data);
-	char *splitChange(StockData *stockdata, char *data);
+	char *splitChange(StockData *stockdata, char *data, StockQuote *quote);
 
 	/* FOR COLOR */
 
@@ -133,7 +139,7 @@
 
 	
 
-        gint font_cb( GtkWidget *widget, void *data ) ;
+        void font_cb(GnomeFontPicker *gfp, const gchar *font_name, gpointer data) ;
         gint OkClicked( GtkWidget *widget, void *data ) ;
         gint QuitFontDialog( GtkWidget *widget, void *data ) ;
 	/* end font funcs and vars */
@@ -141,23 +147,24 @@
 	/*-----------------------------------------------------------------*/
 	static void load_fonts(StockData *stockdata)
 	{
+		PangoFontDescription *font;
 		
-		if (stockdata->new_font != NULL) {
-			if (stockdata->whichlabel == 1)
-				stockdata->my_font = gdk_fontset_load(stockdata->new_font);
-			else
-				stockdata->small_font = gdk_fontset_load(stockdata->new_font);
+		if (stockdata->my_font)
+			gdk_font_unref (stockdata->my_font);
+		font = pango_font_description_from_string (stockdata->props.font);
+		stockdata->my_font = gdk_font_from_description (font);
+		pango_font_description_free (font);
+		
+
+		if (!stockdata->extra_font) {
+			stockdata->extra_font = gdk_font_load ("-*-symbol-medium-r-normal-*-*-140-*-*-p-*-adobe-fontspecific");
 		}
-
-		if (!stockdata->my_font)
-			stockdata->my_font = gdk_fontset_load (stockdata->props.font);
-
-		if (!stockdata->extra_font)
-			stockdata->extra_font = gdk_fontset_load ("fixed");
-
-		if (!stockdata->small_font)
-			stockdata->small_font = gdk_fontset_load (stockdata->props.font2);
-
+		
+		if (stockdata->small_font)
+				gdk_font_unref(stockdata->small_font);
+		font = pango_font_description_from_string (stockdata->props.font2);
+		stockdata->small_font = gdk_font_from_description (font);
+		pango_font_description_free (font);
 
 		/* If fonts do not load */
 		if (!stockdata->my_font)
@@ -167,20 +174,22 @@
 			
 			if (stockdata->extra_font)
 				gdk_font_unref(stockdata->extra_font);
-			stockdata->extra_font = gdk_fontset_load("fixed");
+			font = pango_font_description_from_string ("fixed 12");
+			stockdata->extra_font = gdk_font_from_description (font);
+			pango_font_description_free (font);
 			stockdata->symbolfont = 0;
 		}
 		else {
 			if (stockdata->extra_font)
 				gdk_font_unref(stockdata->extra_font);
-			stockdata->extra_font = gdk_fontset_load ("fixed");
+			stockdata->extra_font = gdk_font_load ("-*-symbol-medium-r-normal-*-*-140-*-*-p-*-adobe-fontspecific");
 			stockdata->symbolfont = 1;
 
 		}
 		if (!stockdata->small_font) {
 			if (stockdata->small_font)
 				gdk_font_unref(stockdata->small_font);
-			stockdata->small_font = gdk_fontset_load("fixed");
+			stockdata->small_font = gdk_font_load("fixed");
 		}
 
 	}
@@ -189,9 +198,9 @@
 static void xfer_callback (GnomeVFSAsyncHandle *handle, GnomeVFSXferProgressInfo *info, gpointer data)
 {
 	StockData *stockdata = data;
-g_print ("%d \n", info->phase);
+
 	if (info->phase == GNOME_VFS_XFER_PHASE_COMPLETED) {
-g_print ("completed \n");
+
 		if (!configured(stockdata)) {
 			reSetOutputArray(stockdata);
 			fprintf(stderr, "No data!\n");
@@ -205,23 +214,25 @@ g_print ("completed \n");
 static gint updateOutput(gpointer data)
 {
 	StockData *stockdata = data;
-	GList *sources = NULL, *dests = NULL;
+	GList *sources, *dests;
 	GnomeVFSURI *source_uri, *dest_uri;
-	char *source_text_uri;
+	char *source_text_uri, *dest_text_uri;
 	GnomeVFSAsyncHandle *vfshandle;
 
 	source_text_uri = g_strconcat("http://finance.yahoo.com/q?s=",
 				      stockdata->props.tik_syms,
 				      "&d=v2",
 				      NULL);
-g_print ("%s \n", source_text_uri);
+
 	source_uri = gnome_vfs_uri_new(source_text_uri);
-	sources = g_list_append(sources, source_uri);
+	sources = g_list_append(NULL, source_uri);
 	g_free(source_text_uri);
-g_print ("%s \n", stockdata->configFileName);
-	dest_uri = gnome_vfs_uri_new(stockdata->configFileName);
-	dests = g_list_append(dests, dest_uri);
-#if 0
+	dest_text_uri = g_strconcat ("file://",stockdata->configFileName, NULL);
+
+	dest_uri = gnome_vfs_uri_new(dest_text_uri);
+	dests = g_list_append(NULL, dest_uri);
+	g_free (dest_text_uri);
+
 	if (GNOME_VFS_OK !=
 	    gnome_vfs_async_xfer(&vfshandle, sources, dests,
 				 GNOME_VFS_XFER_DEFAULT,
@@ -229,21 +240,13 @@ g_print ("%s \n", stockdata->configFileName);
 				 GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
 				 GNOME_VFS_PRIORITY_DEFAULT,
 				 (GnomeVFSAsyncXferProgressCallback) xfer_callback,
-				 stockdata, 
-				 NULL, NULL)) {
+				 stockdata, NULL, NULL)) {
 		GnomeVFSXferProgressInfo info;
-g_print ("hello \n");
+
 		info.phase = GNOME_VFS_XFER_PHASE_COMPLETED;
 		xfer_callback(NULL, &info, stockdata);
 	}
-#else
-	gnome_vfs_xfer_uri (source_uri, dest_uri, GNOME_VFS_XFER_DEFAULT,
-			    GNOME_VFS_XFER_ERROR_MODE_ABORT,
-			    GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
-			    NULL,
-			    NULL);
-	configured (stockdata);
-#endif
+
 	g_list_free(sources);
 	g_list_free(dests);
 
@@ -264,7 +267,7 @@ g_print ("hello \n");
 									   "tik_syms",
 									   NULL);
 		if (!stockdata->props.tik_syms)
-			stockdata->props.tik_syms = g_strdup ("cald+rhat+corl");
+			stockdata->props.tik_syms = g_strdup ("^DJI+^IXIC+^GSPC");
 		stockdata->props.output = panel_applet_gconf_get_bool (applet,
 									  "output",
 									  NULL);
@@ -372,7 +375,7 @@ g_print ("hello \n");
 		int flag=0;
 		char *section = NULL;
 		char *ptr;
-g_print ("parse \n");
+
 		if (strlen(line) > 64) AllOneLine=1;
 
 		if (AllOneLine) {
@@ -436,7 +439,6 @@ g_print ("parse \n");
 			}
 			linenum++;
 		}
-		g_print ("%s \n", change);
 		sprintf(result,"%s:%s:%s:%s",
 				symbol,price,change,percent);			
 		return(result);
@@ -453,7 +455,7 @@ g_print ("parse \n");
 		static FILE *CONFIG;
 
 		CONFIG = fopen((const char *)stockdata->configFileName,"r");
-g_print ("configured \n");
+
 		retVar = 0;
 
 		/* clear the output variable */
@@ -743,6 +745,8 @@ g_print ("configured \n");
 		StockData *stockdata = data;
 		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
 		
+		if (gtk_toggle_button_get_active (button) == stockdata->props.output)
+			return;
 		stockdata->props.output = gtk_toggle_button_get_active (button);
 		panel_applet_gconf_set_bool (applet,"output",
 					     stockdata->props.output, NULL);
@@ -767,9 +771,19 @@ g_print ("configured \n");
 		StockData *stockdata = data;
 		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
 		
+		if (stockdata->props.arrows == gtk_toggle_button_get_active (button))
+			return;
+			
 		stockdata->props.arrows = gtk_toggle_button_get_active (button);
 		panel_applet_gconf_set_bool (applet,"arrows",
 					     stockdata->props.arrows, NULL);
+		load_fonts (stockdata);
+		if (!configured(stockdata)) {
+			reSetOutputArray(stockdata);
+			fprintf(stderr, "No data!\n");
+			setOutputArray(stockdata,
+				       _("No data available or properties not set"));
+		}
 					     
 	}
 	
@@ -792,7 +806,112 @@ g_print ("configured \n");
 		}
 					     
 	}
+	
+	static void
+	proxy_toggled (GtkToggleButton *button, gpointer data)
+	{
+		StockData *stockdata = data;
+    		GConfClient *client = gconf_client_get_default ();
+    		gboolean toggled;	
+	
+    		toggled = gtk_toggle_button_get_active(button);
+    		gtk_widget_set_sensitive(stockdata->proxy_url_entry, toggled);
+    		gtk_widget_set_sensitive(stockdata->proxy_user_entry, toggled);
+    		gtk_widget_set_sensitive(stockdata->proxy_port_entry, toggled);
+    		gtk_widget_set_sensitive(stockdata->proxy_passwd_entry, toggled);
+    		gtk_widget_set_sensitive(stockdata->proxy_auth_button, toggled);
 
+    		gconf_client_set_bool (client, "/system/gnome-vfs/use-http-proxy", 
+    			   toggled, NULL);		
+	}	
+
+	static gboolean
+	proxy_port_changed (GtkWidget *entry, GdkEventFocus *event, gpointer data)
+	{
+    		GConfClient *client = gconf_client_get_default ();
+    		gchar *text;
+    		gint port;
+
+    		text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+    
+    		if (!text) 
+    			return FALSE;
+    		port = atoi (text);
+    		g_free (text);
+    
+    		gconf_client_set_int (client, "/system/gnome-vfs/http-proxy-port", 
+    			  port, NULL);
+    		
+    		return FALSE;
+
+	}
+
+	static void
+	proxy_auth_toggled (GtkToggleButton *button, gpointer data)
+	{
+    		GConfClient *client = gconf_client_get_default ();
+    		gboolean toggled;
+	
+    		toggled = gtk_toggle_button_get_active(button);
+    		gconf_client_set_bool (client, "/system/gnome-vfs/use-http-proxy-authorization", 
+    			   toggled, NULL);
+	}
+
+	static gboolean
+	proxy_url_changed (GtkWidget *entry, GdkEventFocus *event, gpointer data)
+	{
+    		GConfClient *client = gconf_client_get_default ();
+    		gchar *text;
+
+    		text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+    
+    		if (!text) 
+    			return FALSE;
+    
+    		gconf_client_set_string (client, "/system/gnome-vfs/http-proxy-host", 
+    			     text, NULL);
+    		g_free (text);
+    		
+    		return FALSE;	
+	}
+
+	static gboolean
+	proxy_user_changed (GtkWidget *entry, GdkEventFocus *event, gpointer data)
+	{
+    		GConfClient *client = gconf_client_get_default ();
+    		gchar *text;
+   
+    		text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+    
+    		if (!text)
+   			return FALSE;
+
+    		gconf_client_set_string (client, "/system/gnome-vfs/http-proxy-authorization-user", 
+    			     text, NULL); 
+    		g_free (text);
+    		
+    		return FALSE;
+
+	}
+	
+	static gboolean
+	proxy_password_changed (GtkWidget *entry, GdkEventFocus *event, gpointer data)
+	{
+    		GConfClient *client = gconf_client_get_default ();
+    		gchar *text;
+   
+    		text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+    
+    		if (!text)
+   			return FALSE;
+
+    		gconf_client_set_string (client, "/system/gnome-vfs/http-proxy-authorization-password", 
+    			     text, NULL);
+    		g_free (text);
+    		
+    		return FALSE;
+	}
+	
 	static void
 	add_symbol (GtkEntry *entry, gpointer data)
 	{
@@ -805,9 +924,16 @@ g_print ("configured \n");
 		gchar *tmp;
 		
 		symbol = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
-		if (!symbol || (strlen (symbol) < 1))
+		if (!symbol)
 			return;
 		
+		g_strstrip (symbol);
+		
+		if (strlen (symbol) < 1) {
+			g_free (symbol);
+			return;
+		}
+		
 		tmp = stockdata->props.tik_syms;
 		stockdata->props.tik_syms = g_strconcat (tmp, "+", symbol, NULL);
 		panel_applet_gconf_set_string (applet, "tik_syms", 
@@ -822,6 +948,7 @@ g_print ("configured \n");
 					    0, symbol, -1);
 					    
 		gtk_entry_set_text (entry, "");
+		g_free (symbol);
 		
 	}
 	
@@ -847,7 +974,6 @@ g_print ("configured \n");
 		if (!symbol)
 			return;
 		
-		g_print ("%s \n", symbol);
 		tmp = stockdata->props.tik_syms;
 		/* don't add the "+" if the symbol is the first one */
 		if (stockdata->props.tik_syms)
@@ -891,92 +1017,38 @@ g_print ("configured \n");
 		
 	}
 
-#ifdef FIXME
-	/*-----------------------------------------------------------------*/
-	static void apply_cb( GtkWidget *widget, void *data ) {
-
-		char *tmpText;
-#ifdef FIXME
-		if (new_font != NULL) {
-			if (whichlabel == 1) 
-				props.font = g_strdup(new_font);
-			else
-				props.font2 = g_strdup(new_font);
-		}
+	void font_cb(GnomeFontPicker *gfp, const gchar *font_name, gpointer data) {
+		StockData *stockdata = data;
+		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
 		
+		if (!font_name)
+			return; 
+		
+		if (stockdata->props.font)
+			g_free (stockdata->props.font);
+		stockdata->props.font = g_strdup (font_name);
+		load_fonts (stockdata);
+		panel_applet_gconf_set_string (applet,"font",
+					       stockdata->props.font, NULL);
 
-		properties_set(TRUE);
-#endif
 	}
 
-
-	/*-----------------------------------------------------------------*/
-        static gint font_selector( GtkWidget *widget, void *data ) {
-
-		if (!fontDialog) {
-			fontDialog = gtk_font_selection_dialog_new("Font Selector");
-			gtk_signal_connect (GTK_OBJECT (GTK_FONT_SELECTION_DIALOG(fontDialog)->ok_button),
-					    "clicked",
-					    GTK_SIGNAL_FUNC(OkClicked),fontDialog);
-            		gtk_signal_connect_object(GTK_OBJECT(GTK_FONT_SELECTION_DIALOG(fontDialog)->cancel_button),
-						  "clicked",
-						  GTK_SIGNAL_FUNC(gtk_widget_destroy),
-						  GTK_OBJECT(fontDialog));
-            		gtk_signal_connect (GTK_OBJECT (fontDialog), "destroy",
-					    GTK_SIGNAL_FUNC(QuitFontDialog),
-					    fontDialog);
+        /*-----------------------------------------------------------------*/
+	static void font2_cb(GnomeFontPicker *gfp, const gchar *font_name, gpointer data) {
+		StockData *stockdata = data;
+		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
+		
+		if (!font_name)
+			return;
 			
-            		gtk_widget_show(fontDialog);
-		} else
-			gdk_window_raise(fontDialog->window);
-		
-		return FALSE;
-	}
-#endif	
-        /*-----------------------------------------------------------------*/
+		stockdata->props.font2 = g_strdup (font_name);
+		load_fonts (stockdata);
+		panel_applet_gconf_set_string (applet,"font2",
+					       stockdata->props.font2, NULL);
 
-	gint font_cb(GtkWidget *widget, gpointer data) {
-#ifdef FIXME
-		whichlabel = 1;
-		font_selector(widget,data);
-#endif
-		return FALSE;
 	}
 
-        /*-----------------------------------------------------------------*/
-	static gint font2_cb(GtkWidget *widget, gpointer data) {
-#ifdef FIXME
-		whichlabel = 2;
-		font_selector(widget,data);
-#endif
-		return FALSE;
-	}
-
-        /*-----------------------------------------------------------------*/
-        gint OkClicked( GtkWidget *widget, void *fontDialog ) {
-#ifdef FIXME
-                gchar *newFont = NULL;
-
-
-                GtkFontSelectionDialog *fsd = 
-			GTK_FONT_SELECTION_DIALOG(fontDialog);
-
-                newFont = gtk_font_selection_dialog_get_font_name(fsd);
-                new_font = g_strdup(newFont);
-                gtk_widget_destroy(fontDialog);
-#endif
-		return FALSE;
-        }
-
-        /*-----------------------------------------------------------------*/
-        gint QuitFontDialog( GtkWidget *widget, void *data ) {
-        
-		/*fontDialog = NULL;*/
-	
-		return FALSE;
-        }
-
-	static void populatelist(StockData *stockdata, GtkWidget *list) {
+        static void populatelist(StockData *stockdata, GtkWidget *list) {
 	
 		gchar *symbol;
 		gchar *syms;
@@ -988,24 +1060,29 @@ g_print ("configured \n");
 
 		if ((temp=strtok(syms,"+")))
 			symbol = g_strdup(temp);
-
+		
 		model = gtk_tree_view_get_model (GTK_TREE_VIEW (list));
 		while (symbol) {
 			gtk_list_store_append (GTK_LIST_STORE (model), &row);
 			gtk_list_store_set (GTK_LIST_STORE (model), &row, 
 					    0, symbol, -1);
-			if ((temp=strtok(NULL,"+")))
+			g_free (symbol);
+			if ((temp=strtok(NULL,"+"))) 
 				symbol = g_strdup(temp);
 			else
 				symbol=NULL;
 		}
-
+		
 		if ((temp=strtok(NULL,""))) {
 			symbol = g_strdup(temp);
 			gtk_list_store_append (GTK_LIST_STORE (model), &row);
 			gtk_list_store_set (GTK_LIST_STORE (model), &row, 
 					    0, symbol, -1);
+			g_free (symbol);
 		}
+		
+		g_free (syms);
+		
 	}
 
 
@@ -1087,7 +1164,7 @@ g_print ("configured \n");
 		gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 	
 		mainhbox = gtk_hbox_new(FALSE,5);
-		gtk_box_pack_start(GTK_BOX(mainhbox),swindow,FALSE,FALSE,0);
+		gtk_box_pack_start(GTK_BOX(mainhbox),swindow,TRUE,TRUE,0);
 		gtk_box_pack_start(GTK_BOX(mainhbox),vbox,FALSE,FALSE,0);
 
 
@@ -1096,10 +1173,135 @@ g_print ("configured \n");
 
 	}
 	
+	static GtkWidget *
+	create_proxy_box (StockData *stockdata)
+	{
+		GtkWidget *vbox;
+		GtkWidget *hbox, *button, *label;
+		GConfClient *client = gconf_client_get_default ();
+		gboolean use_proxy, use_proxy_auth;
+    		gint proxy_port;
+    		gchar *string;
+    		gchar *proxy_url, *proxy_user, *proxy_psswd;
+		
+		use_proxy = 
+    			gconf_client_get_bool (client, 
+    					       "/system/gnome-vfs/use-http-proxy", 
+    					       NULL);
+    		use_proxy_auth = gconf_client_get_bool (client, 
+    			"/system/gnome-vfs/use-http-proxy-authorization", 
+    			NULL);
+    		proxy_url = gconf_client_get_string (client, 
+    			"/system/gnome-vfs/http-proxy-host", NULL);
+    		proxy_user = gconf_client_get_string (client, 
+    		 	"/system/gnome-vfs/http-proxy-authorization-user", NULL);
+    		proxy_psswd = gconf_client_get_string (client, 
+    		 	"/system/gnome-vfs/http-proxy-authorization-password", NULL);
+    		proxy_port = gconf_client_get_int (client, 
+    		 	"/system/gnome-vfs/http-proxy-port", NULL);
+		
+		vbox = gtk_vbox_new (FALSE, 4);
+		gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
+		
+		button = gtk_check_button_new_with_label (_("Use HTTP proxy"));
+    		gtk_box_pack_start (GTK_BOX (vbox), button, 
+    				    FALSE, FALSE, 0);
+    		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), use_proxy);
+   		g_signal_connect (G_OBJECT (button), "toggled",
+    		       		  G_CALLBACK (proxy_toggled), stockdata);
+
+    		hbox = gtk_hbox_new (FALSE, 2);
+    		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    
+    		label = gtk_label_new (_("Location :"));
+    		gtk_box_pack_start (GTK_BOX (hbox), label, 
+    			    FALSE, FALSE, 0);
+    
+    		stockdata->proxy_url_entry = gtk_entry_new ();
+    		gtk_widget_show (stockdata->proxy_url_entry);
+    		gtk_box_pack_start (GTK_BOX (hbox), stockdata->proxy_url_entry, 
+    			    FALSE, FALSE, 0);
+    		g_signal_connect (G_OBJECT (stockdata->proxy_url_entry), "focus_out_event",
+    		          G_CALLBACK (proxy_url_changed), stockdata);
+
+    		hbox = gtk_hbox_new (FALSE, 2);
+    		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    
+    		label = gtk_label_new (_("Port :"));
+    		gtk_widget_show (label);
+    		gtk_box_pack_start (GTK_BOX (hbox), label, 
+    			    FALSE, FALSE, 0);
+    			
+    		stockdata->proxy_port_entry = gtk_entry_new ();
+    		gtk_box_pack_start (GTK_BOX (hbox), stockdata->proxy_port_entry, 
+    				    FALSE, FALSE, 0);
+    		g_signal_connect (G_OBJECT (stockdata->proxy_port_entry), "focus_out_event",
+    		          G_CALLBACK (proxy_port_changed), stockdata);
+    
+    		stockdata->proxy_auth_button = gtk_check_button_new_with_label (_("Proxy requires a uername and password"));
+    		gtk_box_pack_start (GTK_BOX (vbox), stockdata->proxy_auth_button, 
+    				    FALSE, FALSE, 0);
+    		gtk_toggle_button_set_active 
+    			(GTK_TOGGLE_BUTTON (stockdata->proxy_auth_button), use_proxy_auth);
+        	g_signal_connect (G_OBJECT (stockdata->proxy_auth_button), "toggled",
+    		       G_CALLBACK (proxy_auth_toggled), stockdata);
+    		       
+    		hbox = gtk_hbox_new (FALSE, 2);
+    		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    
+    		label = gtk_label_new (_("Username:"));
+    		gtk_box_pack_start (GTK_BOX (hbox), label, 
+    			    FALSE, FALSE, 0);
+    
+    		stockdata->proxy_user_entry = gtk_entry_new ();
+    		gtk_box_pack_start (GTK_BOX (hbox), stockdata->proxy_user_entry, 
+    			    FALSE, FALSE, 0);
+    		g_signal_connect (G_OBJECT (stockdata->proxy_user_entry), "focus_out_event",
+    		          G_CALLBACK (proxy_user_changed), stockdata);
+
+    		hbox = gtk_hbox_new (FALSE, 2);
+    		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    
+    		label = gtk_label_new (_("Password:"));
+    		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+
+    		stockdata->proxy_passwd_entry = gtk_entry_new ();
+    		gtk_entry_set_visibility (GTK_ENTRY (stockdata->proxy_passwd_entry), FALSE);
+    		gtk_box_pack_start (GTK_BOX (hbox), stockdata->proxy_passwd_entry, 
+    			    FALSE, FALSE, 0);
+    		g_signal_connect (G_OBJECT (stockdata->proxy_passwd_entry), 
+    			          "focus_out_event",
+    		                  G_CALLBACK (proxy_password_changed), stockdata);
+    		 	
+    		gtk_entry_set_text(GTK_ENTRY(stockdata->proxy_url_entry), 
+    		       proxy_url ? 
+    		       proxy_url : "");
+    		gtk_entry_set_text(GTK_ENTRY(stockdata->proxy_passwd_entry), 
+    		       proxy_psswd ? 
+    		       proxy_psswd : "");
+    		gtk_entry_set_text(GTK_ENTRY(stockdata->proxy_user_entry), 
+    		       proxy_user ? 
+    		       proxy_user : "");
+    		string = g_strdup_printf ("%d", proxy_port);
+    		gtk_entry_set_text(GTK_ENTRY(stockdata->proxy_port_entry), string);
+    		g_free (string); 
+    		
+    		gtk_widget_set_sensitive (stockdata->proxy_auth_button, use_proxy);
+    		gtk_widget_set_sensitive (stockdata->proxy_url_entry, use_proxy);
+    		gtk_widget_set_sensitive (stockdata->proxy_port_entry, use_proxy);
+    		gtk_widget_set_sensitive (stockdata->proxy_passwd_entry, use_proxy);
+    		gtk_widget_set_sensitive (stockdata->proxy_user_entry, use_proxy);
+    			
+		gtk_widget_show_all (vbox);
+		return vbox;
+	} 
+	
 	static void
 	response_cb (GtkDialog *dialog, gint id, gpointer data)
 	{
+		StockData *stockdata = data;
 		gtk_widget_destroy (GTK_WIDGET (dialog));
+		stockdata->pb = NULL;
 		
 	}
 
@@ -1110,7 +1312,7 @@ g_print ("configured \n");
 		GtkWidget * notebook;
 		GtkWidget * vbox;
 		GtkWidget * vbox2;
-		GtkWidget * vbox3;
+		GtkWidget * vbox3, * vbox4;
 		GtkWidget * hbox3;
 		GtkWidget *hbox;
 		GtkWidget * label;
@@ -1120,8 +1322,14 @@ g_print ("configured \n");
 		GtkObject *timeout_a;
 		GtkWidget *upColor, *downColor, *upLabel, *downLabel;
 		GtkWidget *check, *check2, *check3, *check4, *fontButton;
+		GtkWidget *font_picker;
 
 		int ur,ug,ub, dr,dg,db; 
+		
+		if (stockdata->pb) {
+			gtk_window_present (GTK_WINDOW (stockdata->pb));
+			return;
+		}
 
 		stockdata->pb = gtk_dialog_new_with_buttons (_("Stock Ticker Properties"), 
 							     NULL,
@@ -1243,26 +1451,27 @@ g_print ("configured \n");
 		vbox3 = gtk_vbox_new(FALSE, 5); 
 		hbox3 = gtk_hbox_new(FALSE, 5);
 		label5 = gtk_label_new(_("Stock Symbol:"));
-                fontButton = gtk_button_new_with_label(_("Select Font"));
-                gtk_box_pack_start_defaults(GTK_BOX(hbox3),label5);
-                gtk_box_pack_start_defaults(GTK_BOX(hbox3),fontButton);
-                gtk_box_pack_start_defaults(GTK_BOX(vbox3),hbox3);
-                gtk_signal_connect_object(GTK_OBJECT(fontButton),"clicked",
-                                GTK_SIGNAL_FUNC(font_cb),GTK_OBJECT(stockdata->pb));
-                gtk_signal_connect_object(GTK_OBJECT(fontButton),"clicked",
-                                GTK_SIGNAL_FUNC(changed_cb),GTK_OBJECT(stockdata->pb));
 
+		font_picker = gnome_font_picker_new ();
+		gnome_font_picker_set_font_name (GNOME_FONT_PICKER (font_picker),
+						 stockdata->props.font);
+		gtk_box_pack_start_defaults(GTK_BOX(hbox3),label5);
+                gtk_box_pack_start_defaults(GTK_BOX(hbox3),font_picker);
+                gtk_box_pack_start_defaults(GTK_BOX(vbox3),hbox3);
+                g_signal_connect (G_OBJECT (font_picker), "font_set",
+                		  G_CALLBACK (font_cb), stockdata);
+                                
 		hbox3 = gtk_hbox_new(FALSE, 5);
 		label5 = gtk_label_new(_("Stock Change:"));
-                fontButton = gtk_button_new_with_label(_("Select Font"));
+                font_picker = gnome_font_picker_new ();
+                gnome_font_picker_set_font_name (GNOME_FONT_PICKER (font_picker),
+						 stockdata->props.font2);
                 gtk_box_pack_start_defaults(GTK_BOX(hbox3),label5);
-                gtk_box_pack_start_defaults(GTK_BOX(hbox3),fontButton);
+                gtk_box_pack_start_defaults(GTK_BOX(hbox3),font_picker);
                 gtk_box_pack_start_defaults(GTK_BOX(vbox3),hbox3);
-                gtk_signal_connect_object(GTK_OBJECT(fontButton),"clicked",
-                                GTK_SIGNAL_FUNC(font2_cb),GTK_OBJECT(stockdata->pb));
-                gtk_signal_connect_object(GTK_OBJECT(fontButton),"clicked",
-                                GTK_SIGNAL_FUNC(changed_cb),GTK_OBJECT(stockdata->pb));
-
+                g_signal_connect (G_OBJECT(font_picker),"font_set",
+                                  G_CALLBACK(font2_cb),stockdata);
+                
 		gtk_box_pack_start_defaults(GTK_BOX(panela),vbox3);
 
 
@@ -1281,18 +1490,14 @@ g_print ("configured \n");
 		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
 		label = gtk_label_new_with_mnemonic (_("_Appearance"));
 		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox2, label);
-		
-
-#if 0
-		gtk_signal_connect_object(GTK_OBJECT(tik_syms_entry), 
-				   "changed",GTK_SIGNAL_FUNC(changed_cb),
-				   GTK_OBJECT(pb));
-#endif
+		label = gtk_label_new_with_mnemonic (_("_Proxy"));
+		vbox4 = create_proxy_box (stockdata);
+		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox4, label);
 
 		gtk_widget_show_all(stockdata->pb);
 		
 		g_signal_connect (G_OBJECT (stockdata->pb), "response",
-				  G_CALLBACK (response_cb), NULL);
+				  G_CALLBACK (response_cb), stockdata);
 
 	}
 
@@ -1342,6 +1547,7 @@ g_print ("configured \n");
 
 		gtk_widget_show(stockdata->drawing_area);
 		gtk_container_add(GTK_CONTAINER(frame),stockdata->drawing_area);
+		
 		gtk_widget_show(frame);
 
 		gtk_box_pack_start(GTK_BOX(vbox),stockdata->leftButton,FALSE,FALSE,0);
@@ -1366,9 +1572,9 @@ g_print ("configured \n");
 
 
 		gtk_widget_show (GTK_WIDGET (applet));
+		
 		create_gc(stockdata);
 
-
 		properties_load(stockdata);
 		properties_set(stockdata,FALSE);
 		
@@ -1380,7 +1586,7 @@ g_print ("configured \n");
 				                   stockdata);
 
 		/* KEEPING TIMER ID FOR CLEANUP IN DESTROY */
-		stockdata->drawTimeID = gtk_timeout_add(100,Repaint,stockdata);
+		stockdata->drawTimeID = gtk_timeout_add(4,Repaint,stockdata);
 		stockdata->updateTimeID = gtk_timeout_add(stockdata->props.timeout * 60000,
 				                          updateOutput,stockdata);
 
@@ -1426,8 +1632,16 @@ g_print ("configured \n");
 			gtk_timeout_remove(stockdata->drawTimeID); }
 		if (stockdata->updateTimeID >0) { 
 			gtk_timeout_remove(stockdata->updateTimeID); }
-		gtk_widget_destroy(stockdata->drawing_area);
-
+		/*gtk_widget_destroy(stockdata->drawing_area);*/
+		
+		if (stockdata->configFileName)
+			g_free (stockdata->configFileName);
+		if (stockdata->my_font)
+			gdk_font_unref (stockdata->my_font);
+		if (stockdata->extra_font)
+			gdk_font_unref (stockdata->extra_font);
+		if (stockdata->small_font)
+			gdk_font_unref (stockdata->small_font);
 	}
 
 
@@ -1468,7 +1682,7 @@ g_print ("configured \n");
 	}
 
 	/*-----------------------------------------------------------------*/
-	char *splitChange(StockData *stockdata,char *data) {
+	char *splitChange(StockData *stockdata,char *data, StockQuote *quote) {
 		char buff[128]="";
 		static char buff2[128]="";
 		char *var1, *var2, *var3, *var4;
@@ -1483,22 +1697,24 @@ g_print ("configured \n");
 			return data;
 
 		if (var3[0] == '+') { 
-			/*if (stockdata->symbolfont)
-				var3[0] = 221;*/
+			if (stockdata->symbolfont)
+				var3[0] = 221;
 			var4[0] = '(';
+			quote->color = GREEN;
 		}
 		else if (var3[0] == '-') {
-			/*if (stockdata->symbolfont)
-				var3[0] = 223;	*/
+			if (stockdata->symbolfont)
+				var3[0] = 223;	
 			var4[0] = '(';
+			quote->color = RED;
 		}
 		else {
 			var3 = g_strdup(_("(No"));
 			var4 = g_strdup(_("Change "));
+			quote->color = WHITE;
 		}
 
 		sprintf(buff2,"%s %s)",var3,var4);
-		g_print ("%s %s change \n", var4, var3);
 		return(buff2);
 	}
 
@@ -1509,19 +1725,12 @@ g_print ("configured \n");
 		char *change;
 
 		price = splitPrice(param1);
-		change = splitChange(stockdata, param1);
+		change = splitChange(stockdata, param1, &quote);
 
 		quote.price = g_strdup(price);
 		quote.change = g_strdup(change);
 
-		if (strstr(change,"-"))
-			quote.color = RED;
-		else if (strstr(change,"+"))
-			quote.color = GREEN;
-		else
-			quote.color = WHITE;
-
-#if 1
+#if 0
 		g_message("Param1: %s\nPrice: %s\nChange: %s\nColor: %d\n\n", param1, price, change, quote.color);
 #endif
 
@@ -1538,7 +1747,7 @@ g_print ("configured \n");
 		GdkColormap *colormap;
 
 		colormap = gtk_widget_get_colormap(stockdata->drawing_area);
-
+		
 		gdk_color_parse(stockdata->props.ucolor, &stockdata->gdkUcolor);
 		gdk_color_alloc(colormap, &stockdata->gdkUcolor);
 
